@@ -798,6 +798,125 @@ class VideoOverlay(RasterLayer):
     attribution = Unicode().tag(sync=True, o=True)
 
 
+class ImageService(Layer):
+    """ImageService class
+
+    Image Service layer for raster data served through a web service
+
+    Attributes
+    ----------
+    url: string, default ""
+        URL to the image service
+    f: string, default "image"
+        response format (use ``"image"`` to stream as bytes)
+    format: string, default "jpgpng"
+        format of exported image
+
+        - ``"jpgpng"``
+        - ``"png"``
+        - ``"png8"``
+        - ``"png24"``
+        - ``"jpg"``
+        - ``"bmp"``
+        - ``"gif"``
+        - ``"tiff"``
+        - ``"png32"``
+        - ``"bip"``
+        - ``"bsq"``
+        - ``"lerc"``
+    pixel_type: string, default "UNKNOWN"
+        data type of the raster image
+
+        - ``"C128"``
+        - ``"C64"``
+        - ``"F32"``
+        - ``"F64"``
+        - ``"S16"``
+        - ``"S32"``
+        - ``"S8"``
+        - ``"U1"``
+        - ``"U16"``
+        - ``"U2"``
+        - ``"U32"``
+        - ``"U4"``
+        - ``"U8"``
+        - ``"UNKNOWN"``
+    no_data: List[int], default []
+        pixel values representing no data
+    no_data_interpretation: string, default ""
+        how to interpret no data values
+
+        - ``"esriNoDataMatchAny"``
+        - ``"esriNoDataMatchAll"``
+    interpolation: string, default ""
+        resampling process for interpolating the pixel values
+
+        - ``"RSP_BilinearInterpolation"``
+        - ``"RSP_CubicConvolution"``
+        - ``"RSP_Majority"``
+        - ``"RSP_NearestNeighbor"``
+    compression_quality: int, default 100
+        lossy quality for image compression
+    band_ids: List[int], default []
+        order of bands to export for multiple band images
+    time: List[string], default []
+        time range for image
+    rendering_rule: dict, default {}
+        rules for rendering
+    mosaic_rule: dict, default {}
+        rules for mosaicking
+    endpoint: string, default "Esri"
+        endpoint format for building the export image URL
+
+        - ``"Esri"``
+    attribution: string, default ""
+        include image service attribution
+    crs: dict, default ipyleaflet.projections.EPSG3857
+        projection used for this image service.
+    interactive: bool, default False
+        emit when clicked for registered callback
+    update_interval: int, default 200
+        minimum time interval to query for updates when panning (ms)
+    """
+
+    _view_name = Unicode('LeafletImageServiceView').tag(sync=True)
+    _model_name = Unicode('LeafletImageServiceModel').tag(sync=True)
+
+    _formats = ['jpgpng', 'png', 'png8', 'png24', 'jpg', 'bmp', 'gif', 'tiff', 'png32', 'bip', 'bsq', 'lerc']
+    _pixel_types = ['C128', 'C64', 'F32', 'F64', 'S16', 'S32', 'S8', 'U1', 'U16', 'U2', 'U32', 'U4', 'U8', 'UNKNOWN']
+    _no_data_interpretations = ['esriNoDataMatchAny', 'esriNoDataMatchAll']
+    _interpolations = ['RSP_BilinearInterpolation', 'RSP_CubicConvolution', 'RSP_Majority', 'RSP_NearestNeighbor']
+
+    url = Unicode().tag(sync=True)
+    f = Unicode('image').tag(sync=True, o=True)
+    format = Enum(values=_formats, default_value='jpgpng').tag(sync=True, o=True)
+    pixel_type = Enum(values=_pixel_types, default_value='UNKNOWN').tag(sync=True, o=True)
+    no_data = List(allow_none=True).tag(sync=True, o=True)
+    no_data_interpretation = Enum(values=_no_data_interpretations, allow_none=True).tag(sync=True, o=True)
+    interpolation = Enum(values=_interpolations, allow_none=True).tag(sync=True, o=True)
+    compression_quality = Unicode().tag(sync=True, o=True)
+    band_ids = List(allow_none=True).tag(sync=True, o=True)
+    time = List(allow_none=True).tag(sync=True, o=True)
+    rendering_rule = Dict({}).tag(sync=True, o=True)
+    mosaic_rule = Dict({}).tag(sync=True, o=True)
+    endpoint = Unicode('Esri').tag(sync=True, o=True)
+    attribution = Unicode('').tag(sync=True, o=True)
+    crs = Dict(default_value=projections.EPSG3857).tag(sync=True)
+    interactive = Bool(False).tag(sync=True, o=True)
+    update_interval = Int(200).tag(sync=True, o=True)
+
+    _click_callbacks = Instance(CallbackDispatcher, ())
+
+    def __init__(self, **kwargs):
+        super(ImageService, self).__init__(**kwargs)
+        self.on_msg(self._handle_mouse_events)
+
+    def _handle_mouse_events(self, _, content, buffers):
+        event_type = content.get('type', '')
+        if event_type == 'click':
+            self._click_callbacks(**content)
+
+
 class Heatmap(RasterLayer):
     """Heatmap class, with RasterLayer as parent class.
 
@@ -2237,7 +2356,7 @@ class Map(DOMWidget, InteractMixin):
 
     # Map options
     center = List(def_loc).tag(sync=True, o=True)
-    zoom = CFloat(default_value=None, allow_none=True).tag(sync=True, o=True)
+    zoom = CFloat(12).tag(sync=True, o=True)
     max_zoom = CFloat(default_value=None, allow_none=True).tag(sync=True, o=True)
     min_zoom = CFloat(default_value=None, allow_none=True).tag(sync=True, o=True)
     zoom_delta = CFloat(1).tag(sync=True, o=True)
